package com.thetus.oss.maven.dependency;

import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.project.ProjectBuilder;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/


/**
 * Abstract base for classes that are used to determine the dependency relationships within a maven project.
 * Mostly contains boilerplate functions for handling construction and filtering.
 */
 public abstract class ADependencyResolver implements IDependencyResolver {
    protected ProjectBuilder m_projectBuilder;
    protected MavenSession m_session;
    protected List<ArtifactFilter> m_filters = new ArrayList<ArtifactFilter>();

    /**
     * Basic constructor, requires only the maven provided components it uses to build out and figure dependencies
     * @param builder used to build projects from pom files and artifacts
     * @param session used to acquire information about repositories, project building settings
     */
    public ADependencyResolver(@NotNull ProjectBuilder builder, @NotNull MavenSession session) {
        m_projectBuilder = builder;
        m_session = session;
    }

    /**
     * Add a filter that can disallow dependencies as they are resolved
     * @param filter filter to add
     */
    @Override
    public void addDependencyFilter(ArtifactFilter filter) {
        m_filters.add(filter);
    }
}
