/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.thetus.oss.maven.dependency;

import org.apache.maven.model.Dependency;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;


/**
 * Simple data container for holding a tree representation of a dependency graph.
 */
public class DependencyNode {
    protected Dependency m_dependency;
    protected List<DependencyNode> m_subDependencies = new ArrayList<DependencyNode>();

    /**
     * Creates a new DependencyNode wrapping the provided dependency, with no sub-dependencies.
     * @param d the dependency to wrap, should only be null for the root node
     */
    DependencyNode(@Nullable Dependency d) {
        m_dependency = d;
    }

    /**
     * Adds a sub dependency node
     * @param n the node to add, should never be null
     */
    public void addSubDependency(@NotNull DependencyNode n) {
        m_subDependencies.add(n);
    }

    /**
     *
     * @return returns the original dependency wrapped by this node
     */
    public Dependency getDependency() {
        return m_dependency;
    }

    /**
     * @return a list of all the sub dependencies of this node
     */
    public List<DependencyNode> getSubDependencies() {
        return m_subDependencies;
    }
}