/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.thetus.oss.maven.dependency;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

/**
 * A source for locally compiled binaries of projects. In maven this means a target/classes/ as opposed to a
 * ~/.m2/repository/.../something.jar
 *
 * User: sbock
 * Date: 5/6/11
 * Time: 9:31 AM
 */
public interface ILocalBinariesSource {
    /**
     * Returns a list of Strings representing filesystem paths to directories or jars that contain or could contain
     * compiled binary forms of the artifact specified.
     *
     * @param groupId groupID of the desired artifact
     * @param artifactId artifactId of the desired artifact
     * @param version version of the desired artifact
     * @param includeTestBinaries whether or not binaries for test files should be included
     * @return A list of the local binary locations for the specified coordinate, in String form
     */
    @Nullable
    public List<String> getLocalBinaryDirectoriesForCoordinate(@NotNull String groupId, @NotNull String artifactId, @NotNull String version, boolean includeTestBinaries);
}
