package com.thetus.oss.maven.hierarchy;

import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;
import org.apache.maven.project.ProjectBuilder;
import org.apache.maven.project.ProjectBuildingException;
import org.jetbrains.annotations.NotNull;

import java.io.File;

/**
 *
 */
public class DefaultMavenProjectHierarchyBuilder implements IMavenProjectHierarchyBuilder {
    protected ProjectBuilder m_projectBuilder;
    protected MavenSession m_session;
    protected Log m_logger;

    public DefaultMavenProjectHierarchyBuilder(@NotNull final ProjectBuilder projectBuilder, @NotNull final MavenSession session, @NotNull final Log logger) {
        m_projectBuilder = projectBuilder;
        m_session = session;
        m_logger = logger;
    }


    @Override
    public MavenProjectHierarchy buildHierarchy(MavenProject project, boolean lookBack, boolean lookExtra) {
        return new MavenProjectHierarchy(m_projectBuilder, m_session, project, m_logger, lookBack, lookExtra);
    }

    @Override
    public MavenProjectHierarchy buildHierarchy(File pomFile, boolean lookBack, boolean lookExtra) throws ProjectBuildingException {
        return new MavenProjectHierarchy(m_projectBuilder, m_session, pomFile, m_logger, lookBack, lookExtra);
    }

    @Override
    public MavenProject buildProject(File pomFile) throws ProjectBuildingException {
        return m_projectBuilder.build(pomFile, m_session.getProjectBuildingRequest()).getProject();
    }

    @Override
    public MavenSession getSession() {
        return m_session;
    }

    @Override
    public ProjectBuilder getProjectBuilder() {
        return m_projectBuilder;
    }
}
