/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.thetus.oss.maven.paths;

import com.thetus.oss.maven.hierarchy.IMavenProjectHierarchyBuilder;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.project.MavenProject;
import org.apache.maven.project.ProjectBuilder;
import org.apache.maven.project.ProjectBuildingException;
import org.jetbrains.annotations.NotNull;

import java.io.File;

/**
 * Abstract base class for the various path builders. Contains primarily boilerplate for construction
 * and settings.
 *
 * @author Samson "Zigurd" Bock - sbock@thetus.com
 */
public abstract class AMavenPathBuilder {
    MavenProject m_project;
    IMavenProjectHierarchyBuilder m_builder;
    boolean m_findRootAggregator = true;

    /**
     * Basic constructor, requiring only maven components and a base project.
     * @param baseProject the project to build paths of
     */
    public AMavenPathBuilder(@NotNull MavenProject baseProject,@NotNull IMavenProjectHierarchyBuilder builder) {
        this.m_project = baseProject;
        this.m_builder = builder;
    }

    /**
     * Basic constructor, requiring only maven components and a pom file to build a base project from.
     * @param pomfile the project to build paths of
     * @throws org.apache.maven.project.ProjectBuildingException if the pom file provided cannot be built into a valid project.
     */
    public AMavenPathBuilder(File pomfile,@NotNull  IMavenProjectHierarchyBuilder builder) throws ProjectBuildingException {
        this.m_builder = builder;
        //this.m_project = this.m_projectBuilder.build(pomfile,session.getProjectBuildingRequest()).getProject();
        this.m_project = this.m_builder.buildProject(pomfile);
    }

    /**
     * Indicates to the path builder whether it should search backwards to see if the base project is part of a larger hierarchy
     * and use the hierarchy during path build-up or not.
     * @param tf true if it should look backward for a larger reactor, false if not
     */
    public void setFindRootAggregatorMode(boolean tf) {
        m_findRootAggregator = tf;
    }

    /**
     * Simple getter for acquiring the base project
     * @return the base project
     */
    protected MavenProject lcl_getBaseProject () {
        return m_project;
    }
}
