/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.thetus.oss.maven.paths;

import com.thetus.oss.maven.dependency.ILocalBinariesSource;
import com.thetus.oss.maven.dependency.ILocalBinariesSource;

import java.util.List;

/**
 * Interface for classes that facilitate builing up a classpath for use with java applications.
 *
 * @author Samson "Zigurd" Bock - sbock@thetus.com
 */
public interface IClasspathBuilder {
    /**
     * Sets whether or not the builder will attempt to find out if whatever it is acting on is part
     * of a larger project
     * @param tf true if the builder should attempt to find a larger reactor, false otherwise
     */
    public void setFindRootAggregatorMode (boolean tf);

    /**
     * Adds a potential source of local binaries to be searched when creating the classpath
     * @param h the local binary source to search in future calls
     */
    public void addLocalBinariesSource (ILocalBinariesSource h);

    /**
     * Sets whether or not the builder will attempt to use local sources (target/classes directories, local .class
     * files, etc) instead of .jars if available
     * @param tf true if local binaries should be used, false otherwise
     */
    public void setUseLocalBinaries (boolean tf);

    /**
     * @param delim the delimiter with which to separate classpath elements
     * @return a string representation fo the built classpath
     */
    public String buildClasspathString (String delim);

    /**
     * @return a {@link List} representation of the built classpath
     */
    public List<String> getClasspathElements ();

    /**
     * determines whether test binaries should be added as well as normal binaries
     * @param b <code>true</code> if test classes/binaries should be used, false otherwise
     */
    public void useTestClasses (boolean b);
}
