/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.thetus.oss.maven.paths;

import java.util.List;

/**
 * Interface for classes that build up a list of paths to source directories. Primarily intended for use
 * with maven.
 *
 * @author Samson "Zigurd" Bock - sbock@thetus.com
 */
public interface ISourcepathBuilder {
    /**
     * Sets whether the builder should attempt to locate a containing project if relevant. In maven this
     * would equate to whether or not to look for the topmost aggregator pom.
     * @param truth <code>true</code> if the root aggregator should be found, <code>false</code> otherwise
     */
    public void setFindRootAggregatorMode (boolean truth);

    /**
     * @param delim the delimiter string to put between individual entries
     * @return a concatenated string listing out all the sourcepath elements, separated by the delimiter string
     */
    public String buildSourcepathString (String delim);

    /**
     * @return a list of all the sourcepath elements
     */
    public List<String> getSourcepathElements ();

    /**
     * Adds path patterns to exclude from the sourcepath
     * @param excludes list of string patterns
     */
    public void addExcludes( List<String> excludes );

    /**
     * Indicates whether the builder should use sources for test code as well as normal code
     * @param b true if test code should be used, false otherwise
     */
    public void useTestSources ( boolean b );
}
